@@ -32,12 +32,14 @@ class FromSQLQuery(ExtractBase):
     """
     Read SQL Query Block. Defines the read SQL Query Operation
 
-    Basic Usage:
+    Basic example:
         >>> import pandas as pd
         >>> from tiny_blocks.extract import FromSQLQuery
+        >>>
         >>> str_conn = "postgresql+psycopg2://user:pass@postgres:5432/db"
         >>> sql = "select * from test"
         >>> read_sql = FromSQLQuery(dsn_conn=str_conn, sql=sql)
+        >>>
         >>> generator = read_sql.get_iter()
         >>> df = pd.concat(generator)
 
