@@ -28,14 +28,15 @@ class ToCSV(LoadBase):
     """
     Write CSV Block. Defines the load to CSV Operation
 
-    Basic Usage:
+    Basic example:
         >>> from tiny_blocks.load import ToCSV
         >>> from tiny_blocks.extract import FromCSV
+        >>>
         >>> from_csv = FromCSV(path="path/to/source.csv")
         >>> to_csv = ToCSV(path="path/to/sink.csv")
-        >>> source = from_csv.get_iter()
-        >>> to_csv.exhaust(source)
-        >>> df = pd.read_csv("path/to/sink.csv", sep="|")
+        >>>
+        >>> generator = from_csv.get_iter()
+        >>> to_csv.exhaust(generator)
 
     See info about Kwargs:
     https://pandas.pydata.org/docs/reference/api/pandas.to_csv.html
