@@ -30,15 +30,16 @@ class ToSQL(LoadBase):
     """
     Load SQL Block. Defines the Loading operation to a SQL Database
 
-    Basic Usage:
+    Basic example:
         >>> from tiny_blocks.extract import FromSQLTable
         >>> from tiny_blocks.load import ToSQL
+        >>>
         >>> str_conn = "postgresql+psycopg2://user:pass@postgres:5432/db"
         >>> from_sql = FromSQLTable(dsn_conn=str_conn, table_name="source")
         >>> to_sql = ToSQL(dsn_conn=str_conn, table_name="sink")
-        >>> source = from_sql.get_iter()
-        >>> to_sql.exhaust(source)
-        >>> df = pd.read_sql_table(table_name="sink", con=str_conn)
+        >>>
+        >>> generator = from_sql.get_iter()
+        >>> to_sql.exhaust(generator)
 
     For more Kwargs info:
     https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_sql.html
