@@ -23,29 +23,35 @@ logger = logging.getLogger(__name__)
 class FanOut:
     """
     Tee the flow into one/multiple pipes.
-    The main pipeline can continue to another transformation blocks or sink.
+    The main pipeline can continue as shown in the example.
 
-    Usage:
+    Usage::
+
+        ... >> FanOut(load1, load2, ..., loadN) >> ...
+
+
+    Examples:
         >>> from tiny_blocks.pipeline import FanOut
         >>> from tiny_blocks.extract import FromCSV
         >>> from tiny_blocks.load import ToSQL, ToCSV
-        >>> from tiny_blocks.transform import DropDuplicates
+        >>> from tiny_blocks.transform import DropDuplicates, Fillna
         >>>
         >>> from_csv = FromCSV(path='/path/to/source.csv')
         >>> drop_dupl = DropDuplicates()
+        >>> fill_na = Fillna(value="Hola Mundo")
         >>> to_csv = ToCSV(path='/path/to/sink.csv')
-        >>> to_sql = ToSQL(dsn_conn='psycopg2+postgres://...')
+        >>> to_sql = ToSQL(dsn_conn='psycopg2+po...', table_name="sink")
         >>>
         >>> from_csv >> FanOut(to_sql) >> drop_dupl >> to_csv
     """
 
-    def __init__(self, *load_blocks: LoadBase):
-        self.load_blocks = load_blocks
+    def __init__(self, *sinks: LoadBase):
+        self.sinks = sinks
 
     def exhaust(self, *sources: Iterator[pd.DataFrame]):
-        for load_block, source in zip(self.load_blocks, sources):
+        for sink, source in zip(self.sinks, sources):
             try:
-                load_block.exhaust(source=source)
+                sink.exhaust(source)
             except Exception as e:
                 logger.error(str(e))
 
@@ -65,8 +71,8 @@ class Pipe:
         return self.source
 
     def __rshift__(
-        self, next: Union[TransformBase | LoadBase | FanOut]
-    ) -> NoReturn | "Pipe":
+        self, next: TransformBase | LoadBase | FanOut
+    ) -> "Pipe" | NoReturn:
         """
         The `>>` operator for the tiny-blocks library.
         """
@@ -76,9 +82,8 @@ class Pipe:
         elif isinstance(next, LoadBase):
             return next.exhaust(source=self.get_iter())
         elif isinstance(next, FanOut):
-            # n sources = a source per each load block
-            # + 1 for the next pipe
-            n = len(next.load_blocks) + 1
+            # a source per each load block + 1 for the next pipe
+            n = len(next.sinks) + 1
             source, *sources = itertools.tee(self.get_iter(), n)
             next.exhaust(*sources)
             return Pipe(source=source)
@@ -92,18 +97,25 @@ class FanIn:
     The next block must accept multiple arguments, for example:
     ``tiny_blocks.tranform.Merge``
 
-    Usage:
+    Usage::
+
+        FanIn(pipe1, pipe2, ..., pipeN) >> ...
+
+
+    Examples:
         >>> from tiny_blocks.extract import FromCSV
-        >>> from tiny_blocks.load import ToSQL
+        >>> from tiny_blocks.load import ToCSV
         >>> from tiny_blocks.pipeline import FanIn
         >>> from tiny_blocks.transform import Merge
+        >>> from tiny_blocks.transform import Fillna
         >>>
-        >>> csv_1 = FromCSV(path='/path/to/file1.csv')
-        >>> csv_2 = FromCSV(path='/path/to/file2.csv')
+        >>> from_csv_1 = FromCSV(path='/path/to/file1.csv')
+        >>> from_csv_2 = FromCSV(path='/path/to/file2.csv')
+        >>> to_csv = ToCSV(path='/path/to/file3.csv')
+        >>> fillna = Fillna(value="Hola Mundo")
         >>> merge = Merge(left_on="ColumnA", right_on="ColumnB")
-        >>> to_sql = ToSQL(dsn_conn='psycopg2+postgres://...')
         >>>
-        >>> FanIn(csv_1, csv_2)  >> merge >> to_sql
+        >>> FanIn(from_csv_1, from_csv_2 >> fillna)  >> merge >> to_csv
     """
 
     def __init__(self, *pipes: Union["ExtractBase", "Pipe"]):
@@ -141,7 +153,7 @@ class Pipeline:
         >>>
         >>> from_csv = FromCSV(path='/path/to/file.csv')
         >>> fill_na = Fillna(value="Hola Mundo")
-        >>> to_sql = ToSQL(dsn_conn='psycopg2+postgres://...')
+        >>> to_sql = ToSQL(dsn_conn='psycopg2+postgr...', table_name="sink")
         >>>
         >>> with Pipeline(name="My Pipeline") as pipe:
         >>>     from_csv >> fill_na >> to_sql
