@@ -24,14 +24,16 @@ class DropDuplicates(TransformBase):
     """
     Drop Duplicates Block. Defines the drop duplicates functionality
 
-    Basic Usage:
+    Basic example:
         >>> import pandas as pd
         >>> from tiny_blocks.transform import DropDuplicates
         >>> from tiny_blocks.extract import FromCSV
+        >>>
         >>> extract_csv = FromCSV(path='/path/to/file.csv')
         >>> drop_duplicates = DropDuplicates()
-        >>> source = extract_csv.get_iter()
-        >>> generator = drop_duplicates.get_iter(source)
+        >>>
+        >>> generator = extract_csv.get_iter()
+        >>> generator = drop_duplicates.get_iter(generator)
         >>> df = pd.concat(generator)
 
     For more Kwargs info:
@@ -57,10 +59,9 @@ class DropDuplicates(TransformBase):
             # select non-duplicated rows. It is also possible to select
             # a non-duplicated subset of rows.
             sql = f"""
-            SELECT * FROM temp
-            WHERE rowid not in
-            (SELECT MIN(rowid) from temp
-            GROUP BY {", ".join(self.subset) if self.subset else "'*'"})
+            SELECT *
+            FROM temp
+            GROUP BY {", ".join(self.subset or chunk.columns.to_list())} ;
             """
 
             # yield records now without duplicates
