@@ -22,14 +22,16 @@ class DropNa(TransformBase):
     """
     Drop Nan Block. Defines the drop None values functionality
 
-    Basic Usage:
+    Basic example:
         >>> import pandas as pd
         >>> from tiny_blocks.transform import DropNa
         >>> from tiny_blocks.extract import FromCSV
+        >>>
         >>> extract_csv = FromCSV(path='/path/to/file.csv')
         >>> drop_na = DropNa()
-        >>> source = extract_csv.get_iter()
-        >>> generator = drop_na.get_iter(source)
+        >>>
+        >>> generator = extract_csv.get_iter()
+        >>> generator = drop_na.get_iter(generator)
         >>> df = pd.concat(generator)
 
     For more Kwargs info:
