@@ -25,14 +25,16 @@ class Fillna(TransformBase):
     """
     Fill Nan Block. Defines the fill Nan values functionality
 
-    Basic Usage:
+    Basic example:
         >>> import pandas as pd
         >>> from tiny_blocks.transform import Fillna
         >>> from tiny_blocks.extract import FromCSV
+        >>>
         >>> extract_csv = FromCSV(path='/path/to/file.csv')
         >>> fill_na = Fillna(value="Hola Mundo")
-        >>> source = extract_csv.get_iter()
-        >>> generator = fill_na.get_iter(source)
+        >>>
+        >>> generator = extract_csv.get_iter()
+        >>> generator = fill_na.get_iter(generator)
         >>> df = pd.concat(generator)
 
     For more Kwargs info:
