@@ -23,14 +23,16 @@ class Rename(TransformBase):
     """
     Rename Block. Defines Rename columns functionality
 
-    Basic Usage:
+    Basic example:
         >>> import pandas as pd
         >>> from tiny_blocks.transform import Rename
         >>> from tiny_blocks.extract import FromCSV
+        >>>
         >>> from_csv = FromCSV(path='/path/to/file.csv')
         >>> sort = Rename(columns={"column_name": "new_column_name"})
-        >>> source = from_csv.get_iter()
-        >>> generator = sort.get_iter(source)
+        >>>
+        >>> generator = from_csv.get_iter()
+        >>> generator = sort.get_iter(generator)
         >>> df = pd.concat(generator)
 
     For more Kwargs info:
