@@ -24,14 +24,16 @@ class Sort(TransformBase):
     """
     Sort Block. Defines the Sorting operation
 
-    Basic Usage:
+    Basic example:
         >>> import pandas as pd
         >>> from tiny_blocks.transform import Sort
         >>> from tiny_blocks.extract import FromCSV
+        >>>
         >>> extract_csv = FromCSV(path='/path/to/file.csv')
         >>> sort = Sort(by=["column_A"], ascending=False)
-        >>> source = extract_csv.get_iter()
-        >>> generator = sort.get_iter(source)
+        >>>
+        >>> generator = extract_csv.get_iter()
+        >>> generator = sort.get_iter(generator)
         >>> df = pd.concat(generator)
     """
 
